@@ -17,18 +17,20 @@ limitations under the License.
 package main
 
 import (
-	"flag"
 	"fmt"
+	"k8s.io/component-base/logs"
 	"os"
-
-	"github.com/kubernetes-incubator/descheduler/cmd/descheduler/app"
+	"sigs.k8s.io/descheduler/cmd/descheduler/app"
 )
 
 func main() {
 	out := os.Stdout
 	cmd := app.NewDeschedulerCommand(out)
 	cmd.AddCommand(app.NewVersionCommand())
-	flag.CommandLine.Parse([]string{})
+
+	logs.InitLogs()
+	defer logs.FlushLogs()
+
 	if err := cmd.Execute(); err != nil {
 		fmt.Println(err)
 		os.Exit(1)
